# pyhough Package

This package provides codes to perform the frequency-Hough transform to search for continuous gravitational waves from asymetrically rotating neutron stars.

In the package, which builds off of spectrograms created by Pyfstat, one can create a time/frequency peakmap, doppler correct it, and perform the Hough Transform.

The Hough Transform can be applied to either the spectrogrma directly or the peakmap.

